# Suite numérique et leurs convergences

Une **Suite** est une collection **Infinie** et **Ordonée** de nombres réels.

- **Infinie**: Ne s'arrete pas
- **Ordonée**: La place des nombres dans la suite est importante

Nous cherchons à savoir quelle est la valeur de l'élément situé à une position donnée

Une suite est également une fonction de la forme: 

\\[
    n \mapsto x_n
\\]

où n est l'indice (\\(\in\mathbb{N}\\)) et \\(x_n\\) est l'élément (\\(\in\mathbb{R}\\))

### Rappel

Une [fonction](../logique/fonctions.md) est une relation qui à chaques éléments de A fait corespondre **au plus, un** élément de B
\\[
    f: A \to B: x\mapsto y = x^2
\\]

**Atention, A n'est pas forcément le domaine** mais \\(f \subseteq A\\) Toujours

### Le domaine d'une suite

Pour trouver le domaine d'une suite, Nous pouvons chercher ses conditions d'éxistences.
Si ces conditions permettent une suite **infinie** On cherche la valeur ordonnée de départ et le domaine est noté comme suit

- Une **suite** est une fonction tel que
    - \\(I \to \mathbb{R}: n \mapsto x_n \text{ où } I = \mathbb{N}^{\geq k} \text{ où } k\in \mathbb{N}\\)

## Notation

le terme générale d'une suite est noté
\\[
    \Large{(x_n)_{n \in \mathbb{N}^{\geq k}} \subseteq \mathbb{R}}
\\]

Il n'est pas toujours possible de trouver une formule pour une suite (i.e.: suite de nombre premiers)

On peut aussi définir une suite par récurence.
\\[
    (x_n) _{n \in \mathbb{N}} \quad \begin{cases} &x_0=3 \\\\ &\forall n \in\mathbb{N}\quad x _{n+1}= x_n + 4  \end{cases}
\\]

C'est une suite arithmétique de raison 4 (Pour passer à l'élément suivant on ajoute 4)

- Une **suite arithmétique** \\((x_n)_{n\in \mathbb{N}}\\) est définie par:
    - \\(\begin{cases} x_0 \in \mathbb{R} \\\\ \forall n \in \mathbb{N} \quad  x_{n + 1} = x_n + r \end{cases}\\)
        - r est la raison

\\[ \forall n \in \mathbb{N} \quad  x_n = x_0 + n * r \\]

- Une **suite géométrique** \\((x_n)_{n\in \mathbb{N}}\\) est définie par:
    - \\(\begin{cases} x_0 \in \mathbb{R} \\\\ \forall n \in \mathbb{N} \quad  x_{n + 1} = qx_n \end{cases}\\)
        - q est la raison

\\[ \forall n \in \mathbb{N} \quad  x_n = x_0 * q^n \\]


## Convergence 

Une suite \\((x_n)\\) converge vers un réel a si

1) \\(x_n\\) est proche de a lorsque n devient grand
2) La distance entre \\(x_n\\) et a est de plus en plus petite (peut contenir l'élément vers lequel il converge (ex: \\((0)_{n \in \mathbb{N}}\\))
3) La distance entre \\(x_n \text{ et } a\\) peut être rendue aussi petite que je le veux.
    - Donc \\(d(x_n, a) = |x_n - a| \leq \varepsilon, \varepsilon \in \mathbb{R}\\)

- \\( (x\_n) **Converge au sens large** \\)
    - si \\( (x\_n) \xrightarrow[n \to \infty]{}\begin{cases} a \\\\ +\infty \\\\ -\infty\end{cases} \\)

## Unicitée de la limite

- Soient \\((x_n) \subseteq \mathbb{R} \text{ et } a_1, a_2 \in \mathbb{R}\\)
    - Si \\((x_n)\\) converge à la fois vers \\(a_1 \text{ et vers } a_2 \text{ alors } a_1 = a_2\\)

### Notation

### Convergence

Pour exprimer que \\((x_n)\\) converge vers a:
\\[
    x_n \xrightarrow[n \to +\infty]{} a \quad \text{ Ou } \quad \lim_{n \to +\infty}x_n = a 
\\]

### Partie entière

- La partie entière de \\(x\\) se nôte: \\([x]\\)
    - représente le plus grand entier inférieur à \\(x\\)
        - ex: \\([-5.3] = -6\\)

- L'entiers supérieur de \\(y\\) se nôte: \\(\lceil y \rceil\\)
    - représente le plus petit entier supérieur ou égal à \\(y\\)
        - ex: \\(\lceil \pi \rceil = 4\\)


### Regles de calculs

1) \\((a)\_{n \in \mathbb{N}} \xrightarrow[n \to \infty]{} a\\)
2) \\((\frac{1}{n^P}) \xrightarrow[n \to +\infty]{} 0 \text{ si } P > 0\\)
3) \\((a^n) \xrightarrow[n \to +\infty]{} 0 \text{ si } a \in ]-1,1[\\)

- Soient \\(a, b \in \mathbb{R}\\) et \\((x_n) , (y_n) \subseteq \mathbb{R}\\) .
    - On suppose que \\( (x_n) \xrightarrow[n \to \infty]{} a \\)
    - On suppose que \\( (y_n) \xrightarrow[n \to \infty]{} b \\)
        1) \\(\lim\limits_{n \to \infty}x_n + y_n = a + b\\)
        2) \\(\lim\limits_{n \to \infty}x_n * y_n = a * b\\)
        3) \\(\lim\limits_{n \to \infty}\frac{x_n}{y_n} = \frac{a}{b} \text{ si } b \neq 0\\)

## Comparaison des suites

### Théorem de la convergence dominée

Pour se faire nous avons besoin d'une intuition pour a

- Soient \\((x_n), (y_n) \subseteq \mathbb{R}, a \in \mathbb{R} \\)
    1) Si \\((y_n) \xrightarrow[n \to +\infty]{} 0\\)
    2) Si \\(\forall n, |x_n - a| \leq y_n\\)
        - Alors \\(x_n \xrightarrow[x \to +\infty]{} a\\)

### Théorem du Sandwich

- Soient \\((x_n), (y_n), (z_n) \subseteq \mathbb{R}, a \in \mathbb{R} \\)
    1) Si \\((y_n) \xrightarrow[n \to +\infty]{} a \text{ et } (z_n) \xrightarrow[n \to +\infty]{} a\\)
    2) Si \\(\forall n, y_n \leq x_n \leq z_n\\)
        - Alors \\(x_n \xrightarrow[x \to +\infty]{} a\\)

## Les sous-suites

Pour construire une sous-suite, on pioche des éléments. mais:
1) On ne peut pas piocher 2x les mêmes éléments
2) On doit réspécter l'ordre d'apparition des éléments

- Soient \\( (x_n)\_{n \in I}\subseteq \mathbb{R}, (y_n)\_{n \in J}\subseteq \mathbb{R}\\)
    - \\( (y_n)\\) est une **Sous-suite** de \\((x_n)\\) Si:
        - Il existe une [application](../logique/fonctions.md) \\(\varphi : J \to I\\) strictement croissante
        - \\(\forall n \in J , y_n = x\_{\varphi(n)}\\)
    - Alors \\((y\_n) \subseteq (x\_n)\\)

### Proposition

- Soient \\((x\_n) \subseteq \mathbb{R}, (y\_n) \subseteq \mathbb{R} \text{ et } a \in \mathbb{R}\\)
    - Si \\( (x\_n) \xrightarrow[n \to \infty]{} a \\) et que \\((y\_n)\\) est une sous-suite de \\((x\_n)\\)
        - Alors \\((y\_n) \xrightarrow[n \to \infty]{} a\\)

- Soient \\((x_n), (y_n), (z_n) \subseteq \mathbb{R}, a \in \mathbb{R} \\)
    - Si \\((y\_n) \xrightarrow[n \to \infty]{} a \text{ et } (z\_n)\xrightarrow[n \to \infty]{} a\\) deux sous-suites exhaustives de \\((x\_n)\\)
        - Alors, \\((x\_n) \xrightarrow[n \to \infty]{} a\\)


### L'exhaustivitée

- Soient \\( (x\_n)\_{n \in I}, (y\_n)\_{n \in J\_1}, (z\_n)\_{n \in J\_2} \subseteq \mathbb{R}\\)
    - On suppose que \\( (y\_n) \text{ et } (z\_n)\\) sont des sous-suites de \\((x\_n)\\), càd
    \\[
        \exists \varphi\_1 : J\_1 \to I \text{ strictement croissante et } y\_n = x\_{\varphi\_1 (n)} \\\\
        \exists \varphi\_2 : J\_2 \to I \text{ strictement croissante et } z\_n = x\_{\varphi\_2 (n)}
    \\]
        - Alors, \\( (y\_n) et (z\_n)\\) sont des sous-suites **Exhaustives** de \\((x\_n) \text{ si } \varphi\_1(J\_1) \cup \varphi\_2(J\_2) = I\\)

## Convergence vers + ou - \\(\infty\\)

On dit qu'une suite converge vers \\(\pm \infty\\) si les éléments de la suite deviennent aussi grand qu'on veut dans ls positifs/négatifs 
pour autant que n soit suffisament grand

La notation reste inchangée, l'unicitée de la limite est d'applications

\\((x_n)\\) **converge au sens large** si \\(\begin{align}x\_n \xrightarrow[]{} & a ( a \in \mathbb{R} ) \\\\ &+\infty \\\\ &-\infty\end{align}\\)

- \\( n^p \xrightarrow[]{} +\infty \text{ si } p > 0\\)
- \\( a^n \xrightarrow[]{} +\infty \text{ si } a > 1\\)

